//---------------------------------------------------------------------
//  Copyright (C) Microsoft Corporation.  All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
//---------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.Design.Behavior;

namespace DesignSurfaceExtenderLibrary.Extensions
{
    internal class MarginGlyph : BoundsGlyph
    {
        internal MarginGlyph(
            Control c,
            BehaviorService behaviorService,
            IComponentChangeService changeService,
            ISelectionService selectionService,
            IReferenceService referenceService, 
            IServiceProvider serviceProvider,
            Adorner adorner )
            : base( 
                c,
                behaviorService,
                changeService,
                selectionService,
                referenceService,
                serviceProvider,
                new MarginBehavior( serviceProvider ),
                adorner)
        {
            this.propertyName = "Margin";
        }

        protected override void ComputeGeometry()
        {
            Control c = base.RelatedControl;

            Rectangle controlRect =
                this.behaviorService.ControlRectInAdornerWindow( c );

            int halfHitTestWidth = this.hitTestWidth / 2;

            int leftBound = controlRect.Left - c.Margin.Left;
            int topBound = controlRect.Top - c.Margin.Top;
            int widthBound = controlRect.Width + c.Margin.Left + c.Margin.Right;
            int heightBound = controlRect.Height + c.Margin.Top + c.Margin.Bottom;

            this.boundsLeftRect = new Rectangle(
                leftBound - halfHitTestWidth,
                topBound + halfHitTestWidth,
                this.hitTestWidth,
                heightBound - this.hitTestWidth );

            this.boundsTopRect = new Rectangle(
                leftBound + halfHitTestWidth,
                topBound - halfHitTestWidth,
                widthBound - this.hitTestWidth,
                this.hitTestWidth );

            this.boundsRightRect = new Rectangle(
                leftBound + widthBound - halfHitTestWidth,
                topBound + halfHitTestWidth,
                this.hitTestWidth,
                heightBound - this.hitTestWidth );

            this.boundsBottomRect = new Rectangle(
                leftBound + halfHitTestWidth,
                topBound + heightBound - halfHitTestWidth,
                widthBound - this.hitTestWidth,
                this.hitTestWidth );

            this.boundsValue = new Rectangle(
                leftBound,
                topBound,
                widthBound,
                heightBound );
        }
    }
}
